<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../desktopswitch.cpp" line="88"/>
        <source>Switch to desktop %1</source>
        <translation>Byt till skrivbord %1</translation>
    </message>
    <message>
        <location filename="../desktopswitch.cpp" line="149"/>
        <location filename="../desktopswitch.cpp" line="160"/>
        <source>Desktop %1</source>
        <translation>Skrivbord %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation>DesktopSwitch-inställningar</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>Antal rader:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>Skrivbordsnamn:</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>Nummer</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="64"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="72"/>
        <source>If checked, widget will be just an indicator</source>
        <translation>Om markerat är widgeten bara en indikator</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="75"/>
        <source>Show only active desktop</source>
        <translation>Visa endast aktivt skrivbord</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.ui" line="85"/>
        <source>Desktop names</source>
        <translation>Skrivbordsnamn</translation>
    </message>
    <message>
        <location filename="../desktopswitchconfiguration.cpp" line="71"/>
        <source>Desktop %1:</source>
        <translation>Skrivbord %1:</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchUnsupported</name>
    <message>
        <location filename="../desktopswitch.h" line="111"/>
        <source>n/a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../desktopswitch.h" line="113"/>
        <source>DesktopSwitch is unsupported on current platform: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
